@@ -1,7 +1,9 @@
 from . import bbt
 from . import btdx8
+from . import dygod
 
 SITES = {
     'bbt': bbt,
     'btdx8': btdx8,
+    'dygod': dygod,
 }
